@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Git::Sub;
-{
-  $Git::Sub::VERSION = '0.130270';
-}
 # ABSTRACT: git commands imported as System::Sub subs in git:: namespace
-
+$Git::Sub::VERSION = '0.161810';
 use System::Sub ();
 use File::Which ();
 
@@ -36,10 +33,8 @@ sub import
     }
 }
 
-package git;
-{
-  $git::VERSION = '0.130270';
-}
+package # no indexing
+    git;
 
 use subs
     # Common commands
@@ -88,7 +83,7 @@ Git::Sub - git commands imported as L<System::Sub> subs in the git:: namespace
 
 =head1 VERSION
 
-version 0.130270
+version 0.161810
 
 =head1 SYNOPSIS
 
@@ -118,13 +113,24 @@ version 0.130270
 Use L<git|http://www.git-scm.com> commands easily from your Perl program. Each
 git command is imported as a L<System::Sub> DWIM sub.
 
+=head1 EXAMPLES
+
+=over 4
+
+=item *
+
+The L<release script|https://github.com/dolmen/angel-PS1/blob/devel/dist> of
+my L<angel-PS1|https://github.com/dolmen/angel-PS1> project.
+
+=back
+
 =head1 AUTHOR
 
 Olivier Mengué, C<dolmen@cpan.org>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright E<copy> 2013 Olivier Mengué.
+Copyright E<copy> 2016 Olivier Mengué.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl 5 itself.
